==> haskell-base-prelude-1.6.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.6.1
visibility:           public
id:                   base-prelude-1.6.1-7G8REA7jrPZCXST4e4gmWo
key:                  base-prelude-1.6.1-7G8REA7jrPZCXST4e4gmWo
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude
synopsis:             Featureful preludes formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.

    This package will never have any dependencies other than \"base\".

    Besides a rich prelude it provides limited ones like "BasePrelude.DataTypes",
    which only exports the data-types defined across the \"base\" package,
    and "BasePrelude.Operators", which only exports the common operators.

    /Versioning policy/

    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  c735d97894983379f101140d996dfea8
exposed:              True
exposed-modules:
    BasePrelude BasePrelude.DataTypes BasePrelude.Operators

import-dirs:          /usr/lib/ghc-9.0.2/site-local/base-prelude-1.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/base-prelude-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-prelude
hs-libraries:         HSbase-prelude-1.6.1-7G8REA7jrPZCXST4e4gmWo
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.6.1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.6.1.1
visibility:           public
id:                   base-prelude-1.6.1.1-3tVkkfGg30hKb5GU3wo1qD
key:                  base-prelude-1.6.1.1-3tVkkfGg30hKb5GU3wo1qD
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude
synopsis:             Featureful preludes formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    This package will never have any dependencies other than \"base\".
    Besides a rich prelude it provides limited ones like "BasePrelude.DataTypes",
    which only exports the data-types defined across the \"base\" package,
    and "BasePrelude.Operators", which only exports the common operators.
    /Versioning policy/
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  bb353f6a61f283fb3c92e120d86d064d
exposed:              True
exposed-modules:
    BasePrelude BasePrelude.DataTypes BasePrelude.Operators

import-dirs:          /usr/lib/ghc-9.2.8/site-local/base-prelude-1.6.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/base-prelude-1.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-prelude
hs-libraries:         HSbase-prelude-1.6.1.1-3tVkkfGg30hKb5GU3wo1qD
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
